@@ -2,7 +2,7 @@
  *  \file IMP/algebra/SphericalVector3D.h
  *  \brief Stores and converts spherical coordinates
  *
- *  Copyright 2007-2016 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPALGEBRA_SPHERICAL_VECTOR_3D_H
@@ -27,20 +27,18 @@ IMPALGEBRA_BEGIN_NAMESPACE
   \geometry
 */
 class IMPALGEBRAEXPORT SphericalVector3D : public GeometricPrimitiveD<3> {
-  bool check(double r, double theta, double psi);
+  bool check(double r, double theta, double psi) const;
 
  public:
   SphericalVector3D() {};
 
-  //! Constructor that directly converts to spherical coordinates from a vector
-  //! v in Cartesian coordinates
+  //! Construct from a Cartesian coordinate vector
   SphericalVector3D(const Vector3D& v) { set_cartesian_coordinates(v); }
 
-  //! Direct Constructor. A check for the validity of the coords is done
-  //! by default
-  /**
-    Set apply_check to false if you do not want the check
-  **/
+  //! Construct from provided spherical coordinates.
+  /** A check for the validity of the coords is done by default.
+      Set apply_check to false if you do not want the check.
+   */
   SphericalVector3D(double r, double theta, double psi,
                     bool apply_check = true) {
     if (apply_check) {
@@ -67,7 +65,7 @@ class IMPALGEBRAEXPORT SphericalVector3D : public GeometricPrimitiveD<3> {
   }
 
   //! Returns a vector with the Cartesian coordinates
-  Vector3D get_cartesian_coordinates();
+  Vector3D get_cartesian_coordinates() const;
 
   IMP_SHOWABLE_INLINE(SphericalVector3D, out << v_[0] << " , " << v_[1] << " , "
                                              << v_[2]);
