@@ -1,7 +1,7 @@
 /**
  *  \file IMP/algebra/VectorBaseD.h   \brief Simple D vector class.
  *
- *  Copyright 2007-2016 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -227,18 +227,22 @@ class VectorBaseD : public GeometricPrimitiveD<D> {
  */
 template <class VT>
 inline VT get_unit_vector(VT vt) {
-  const double tiny_double = 1e-12;
+  static const double tiny_double =
+    256.0 * std::numeric_limits<double>::epsilon();
   double mag = vt.get_magnitude();
   if (mag > tiny_double) {
-    return vt / mag;
+    VT ret_value= vt/mag;
+    IMP_USAGE_CHECK(std::abs(ret_value.get_magnitude() - 1.0) < 256.0 * tiny_double,
+                    "returned vector is not unit vector");
+    return ret_value;
   } else {
     // avoid division by zero - return random unit v
     // NOTE: (1) avoids vector_generators / SphereD to prevent recursiveness
     //       (2) D might be -1, so use get_dimension()
-    boost::variate_generator<RandomNumberGenerator,
-                             boost::normal_distribution<> >
-        generator(IMP::random_number_generator,
-                  ::boost::normal_distribution<>(0, 1.0));
+    static boost::variate_generator<RandomNumberGenerator,
+      boost::normal_distribution<> >
+      generator(IMP::random_number_generator,
+                ::boost::normal_distribution<>(0, 1.0));
     for (unsigned int i = 0; i < vt.get_dimension(); ++i) {
       vt[i] = generator();
     }
@@ -246,6 +250,26 @@ inline VT get_unit_vector(VT vt) {
   }
 }
 
+//! Returns the magnitude of vt and turns it to a unit vector in place.
+/**
+   @note If the magnitude of this vector is smaller than 1e-12
+         (an arbitrarily selected small number), vt is turned into a unit
+         vector pointing at a random direction.
+ */
+template <class VT>
+inline double get_magnitude_and_normalize_in_place(VT& vt) {
+  const double tiny_double = 1e-12;
+  double mag = vt.get_magnitude();
+  if (mag > tiny_double) {
+    vt /= mag;
+  } else {
+    // avoid division by zero - return random unit v
+    // using get_unit_vector()
+    vt= get_unit_vector(vt);
+  }
+  return mag;
+}
+
 IMPALGEBRA_END_NAMESPACE
 
 #endif /* IMPALGEBRA_VECTOR_BASE_D_H */
