@@ -2,7 +2,7 @@
  *  \file IMP/atom/BrownianDynamicsTAMD.h
  *  \brief Simple molecular dynamics optimizer.
  *
- *  Copyright 2007-2016 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -12,6 +12,7 @@
 #include <IMP/atom/atom_config.h>
 #include "Diffusion.h"
 #include "atom_macros.h"
+#include <IMP/algebra/Sphere3D.h>
 #include <IMP/atom/BrownianDynamics.h>
 #include <IMP/Particle.h>
 #include <IMP/Optimizer.h>
@@ -61,6 +62,10 @@ class SimulationParameters;
     If the skt (stochastic runge kutta) flag is true, the simulation is
     altered slightly to apply the SKT scheme.
 
+    _Time step_
+    The time step is always equal precisely to Simulater::get_maximum_time_step() 
+    when using either Simulator::simulate() or Optimizer::optimize()
+
     \see Diffusion
     \see RigidBodyDiffusion
   */
@@ -99,10 +104,18 @@ class IMPATOMEXPORT BrownianDynamicsTAMD : public BrownianDynamics {
 
  private:
   void advance_coordinates_1(ParticleIndex pi, unsigned int i,
-                             double dtfs, double ikT);
-  void advance_coordinates_0(ParticleIndex pi, unsigned int i,
-                             double dtfs, double ikT);
-  void advance_orientation_0(ParticleIndex pi, double dtfs, double ikT);
+                             double dtfs, double ikT,
+                             double diffusion_coefficient,
+                             algebra::Sphere3D const& xyzr_derivative_pi);
+  void advance_coordinates_0(unsigned int i,
+                             double dtfs, double ikT,
+                             double diffusion_coefficient,
+                             algebra::Sphere3D const& xyzr_derivative_pi,
+                             algebra::Sphere3D& xyzr_access);
+  inline algebra::Rotation3D
+    compute_rotation_0(ParticleIndex pi, double dtfs, double ikT,
+                       double rotational_diffusion_coefficient_table,
+                       double const* torque_tables[]) ;
 };
 
 IMPATOM_END_NAMESPACE
