@@ -2,7 +2,7 @@
  *  \file IMP/atom/SameResiduePairFilter.h
  *  \brief A Score on the distance between a pair of particles.
  *
- *  Copyright 2007-2015 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPATOM_SAME_RESIDUE_PAIR_FILTER_H
@@ -22,11 +22,11 @@ IMPATOM_BEGIN_NAMESPACE
 class IMPATOMEXPORT SameResiduePairFilter : public PairPredicate {
  public:
   SameResiduePairFilter();
-  virtual int get_value_index(kernel::Model *m,
-                              const kernel::ParticleIndexPair &p) const
+  virtual int get_value_index(Model *m,
+                              const ParticleIndexPair &p) const
       IMP_OVERRIDE;
-  virtual kernel::ModelObjectsTemp do_get_inputs(
-      kernel::Model *m, const kernel::ParticleIndexes &pis) const IMP_OVERRIDE;
+  virtual ModelObjectsTemp do_get_inputs(
+      Model *m, const ParticleIndexes &pis) const IMP_OVERRIDE;
   IMP_PAIR_PREDICATE_METHODS(SameResiduePairFilter);
   IMP_OBJECT_METHODS(SameResiduePairFilter);
   ;
