@@ -10,14 +10,14 @@ class Tests(IMP.test.TestCase):
     def _test_simple(self):
         """Check that hierarchies don't have circular ref counts """
         # make sure internal things are created
-        m = IMP.kernel.Model()
-        h = IMP.atom.Hierarchy.setup_particle(IMP.kernel.Particle(m))
+        m = IMP.Model()
+        h = IMP.atom.Hierarchy.setup_particle(IMP.Particle(m))
         del m
         del h
         refcnt = IMP.test.RefCountChecker(self)
-        m = IMP.kernel.Model()
-        h = IMP.atom.Hierarchy.setup_particle(IMP.kernel.Particle(m))
-        hc = IMP.atom.Hierarchy.setup_particle(IMP.kernel.Particle(m))
+        m = IMP.Model()
+        h = IMP.atom.Hierarchy.setup_particle(IMP.Particle(m))
+        hc = IMP.atom.Hierarchy.setup_particle(IMP.Particle(m))
         h.add_child(hc)
         del m
         del hc
@@ -26,14 +26,14 @@ class Tests(IMP.test.TestCase):
 
     def _test_simple_bond(self):
         """Check that bonded don't have circular ref counts """
-        m = IMP.kernel.Model()
-        h = IMP.atom.Bonded.setup_particle(IMP.kernel.Particle(m))
+        m = IMP.Model()
+        h = IMP.atom.Bonded.setup_particle(IMP.Particle(m))
         del m
         del h
         refcnt = IMP.test.RefCountChecker(self)
-        m = IMP.kernel.Model()
-        h = IMP.atom.Bonded.setup_particle(IMP.kernel.Particle(m))
-        hc = IMP.atom.Bonded.setup_particle(IMP.kernel.Particle(m))
+        m = IMP.Model()
+        h = IMP.atom.Bonded.setup_particle(IMP.Particle(m))
+        hc = IMP.atom.Bonded.setup_particle(IMP.Particle(m))
         IMP.atom.create_bond(h, hc, 0)
         del m
         del hc
@@ -43,13 +43,13 @@ class Tests(IMP.test.TestCase):
     def _test_bonded(self):
         """Check that pdbs don't have circular ref counts """
         # charm creates all sorts of things
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         h = IMP.atom.read_pdb(self.get_input_file_name("mini.pdb"), m)
         del m
         del h
-        IMP.base.set_log_level(IMP.MEMORY)
+        IMP.set_log_level(IMP.MEMORY)
         refcnt = IMP.test.RefCountChecker(self)
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         print("reading")
         h = IMP.atom.read_pdb(self.get_input_file_name("mini.pdb"), m)
         del m
@@ -58,7 +58,7 @@ class Tests(IMP.test.TestCase):
 
     def test_rbbonded(self):
         """Check that pdbs with rigid bodies don't have circular ref counts """
-        m = IMP.kernel.Model()
+        m = IMP.Model()
         h = IMP.atom.read_pdb(self.get_input_file_name("mini.pdb"), m)
         rb = IMP.atom.create_rigid_body([h], "test rb")
         # print [x.get_name() for x in rb.get_members()]
@@ -69,8 +69,8 @@ class Tests(IMP.test.TestCase):
         while (True):
             # charm creates all sorts of things
             refcnt = IMP.test.RefCountChecker(self)
-            m = IMP.kernel.Model()
-            p = IMP.kernel.Particle(m)
+            m = IMP.Model()
+            p = IMP.Particle(m)
             p.set_name("TEST")
             del p
             h = IMP.atom.read_pdb(self.get_input_file_name("mini.pdb"), m)
