@@ -2,7 +2,7 @@
  *  \file IMP/foxs/Gnuplot.h   \brief A class for printing gnuplot scripts
  *   for profile viewing
  *
- *  Copyright 2007-2017 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -96,7 +96,7 @@ void Gnuplot::print_fit_script(const IMP::saxs::FitParameters& fp) {
   std::string plt_file_name = pdb_name + "_" + profile_name + ".plt";
   std::string png_file_name = pdb_name + "_" + profile_name + ".png";
   std::string eps_file_name = pdb_name + "_" + profile_name + ".eps";
-  std::string fit_file_name = pdb_name + "_" + profile_name + ".dat";
+  std::string fit_file_name = pdb_name + "_" + profile_name + ".fit";
   // output script
   std::ofstream plt_file(plt_file_name.c_str());
   plt_file.precision(3);
@@ -114,7 +114,7 @@ void Gnuplot::print_fit_script(const IMP::saxs::FitParameters& fp) {
            << "set border 3 back ls 11;f(x)=1" << std::endl;
   plt_file << "plot f(x) notitle lc rgb '#333333'"
            << ", '" << fit_file_name
-           << "' u 1:($2/$3) notitle w lines lw 2.5 lc rgb '#e26261'\n";
+           << "' u 1:(($2-$4)/$3) notitle w lines lw 2.5 lc rgb '#e26261'\n";
 
   // upper fit plot
   plt_file << "set origin 0,0.3;set size 1,0.69; set bmargin 0; set tmargin 1;"
@@ -124,39 +124,40 @@ void Gnuplot::print_fit_script(const IMP::saxs::FitParameters& fp) {
   plt_file << "plot '" << fit_file_name
            << "' u 1:2 t 'Experimental' lc rgb '#333333' pt 6 ps 0.8"
            << ", '" << fit_file_name
-           << "' u 1:3 t 'FoXS χ = " << fp.get_chi()
+           << "' u 1:4 t 'FoXS χ^2 = " << fp.get_chi_square()
+           << "' w lines lw 2.5 lc rgb '#e26261'\n";
+  plt_file << "unset multiplot\n";
+  plt_file << "reset\n";
+  //  plt_file.close();
+  // combined eps plot for paper
+  plt_file << "set terminal postscript eps size 3.5,2.62 color enhanced solid ";
+  plt_file << "linewidth 2.5 font 'Helvetica,22'; set output \""
+           << eps_file_name << "\";" << std::endl;
+
+  plt_file << "set lmargin 2; set rmargin 2;set multiplot\n";
+
+  // lower residuals plot
+  plt_file << "set origin 0,0;set size 1,0.3; set tmargin 0; set bmargin 3;";
+  plt_file << "set ylabel '';set format y '';\n";
+  plt_file << "set xtics nomirror font 'Helvetica,18';\n";
+  plt_file << "set ytics nomirror; set border 3\n";
+  plt_file << "set style line 11 lc rgb '#808080' lt 1;\n";
+  plt_file << "set border 3 back ls 11;f(x)=1" << std::endl;
+  plt_file << "plot f(x) notitle lc rgb '#333333'" << ", '" << fit_file_name
+           << "' u 1:(($2-$4)/$3) notitle w lines lw 2.5 lc rgb '#e26261'\n";
+
+  // upper fit plot
+  plt_file << "set origin 0,0.3;set size 1,0.69; set bmargin 0; set tmargin 1;"
+           << "set xlabel ''; set format x ''; set ylabel 'I(q) log-scale';\n"
+           << "set format y \"10^{%L}\"; set logscale y\n";
+  plt_file <<  "plot '" << fit_file_name
+            << "' u 1:2 t 'Experimental' lc rgb '#333333' pt 6 ps 0.8";
+  plt_file << ", '" << fit_file_name
+           << "' u 1:4 t 'FoXS {/Symbol c}^2 = " << fp.get_chi_square()
            << "' w lines lw 2.5 lc rgb '#e26261'\n";
   plt_file << "unset multiplot\n";
   plt_file << "reset\n";
   plt_file.close();
-  // // combined eps plot for paper
-  // plt_file << "set terminal postscript eps size 3.5,2.62 color enhanced solid
-  // ";
-  // plt_file << "linewidth 2.5 font 'Helvetica,22'; set output \""
-  //          << eps_file_name << "\";" << std::endl;
-
-  // plt_file << "set lmargin 2; set rmargin 2;set multiplot\n";
-
-  // // lower residuals plot
-  // plt_file << "set origin 0,0;set size 1,0.3; set tmargin 0; set bmargin 3;";
-  // plt_file << "set ylabel '';set format y '';\n";
-  // plt_file << "set xtics nomirror font 'Helvetica,18';\n";
-  // plt_file << "set ytics nomirror; set border 3\n";
-  // plt_file << "set style line 11 lc rgb '#808080' lt 1;\n";
-  // plt_file << "set border 3 back ls 11;f(x)=1" << std::endl;
-  // plt_file << "plot f(x) notitle lc rgb '#333333'" << ", '" << fit_file_name
-  //          << "' u 1:($2/$3) notitle w lines lw 2.5 lc rgb '#e26261'\n";
-
-  // // upper fit plot
-  // plt_file << "set origin 0,0.3;set size 1,0.69; set bmargin 0; set tmargin
-  // 1;";
-  // plt_file << "set xlabel ''; set format x ''; set ylabel '';\n";
-  // plt_file <<  "plot '" << fit_file_name
-  //           << "' u 1:(log($2)) notitle lc rgb '#333333' pt 6 ps 0.8";
-  // plt_file << ", '" << fit_file_name
-  //          << "' u 1:(log($3)) t 'FoXS {/Symbol c} = " << fp.get_chi()
-  //          << "' w lines lw 2.5 lc rgb '#e26261'\n";
-  // plt_file << "unset multiplot\n";
 }
 
 void Gnuplot::print_fit_script(
@@ -184,9 +185,9 @@ void Gnuplot::print_fit_script(
     std::string pdb_name = saxs::trim_extension(fps[i].get_pdb_file_name());
     std::string profile_name = saxs::trim_extension(
         basename(const_cast<char*>(fps[i].get_profile_file_name().c_str())));
-    std::string fit_file_name = pdb_name + "_" + profile_name + ".dat";
+    std::string fit_file_name = pdb_name + "_" + profile_name + ".fit";
     plt_file << ", '" << fit_file_name
-             << "' u 1:($2/$3) notitle w lines lw 2.5 lc rgb '#" << hex_color
+             << "' u 1:(($2-$4)/$3) notitle w lines lw 2.5 lc rgb '#" << hex_color
              << "'";
   }
   plt_file << std::endl;
@@ -200,13 +201,13 @@ void Gnuplot::print_fit_script(
     std::string pdb_name = saxs::trim_extension(fps[i].get_pdb_file_name());
     std::string profile_name = saxs::trim_extension(
         basename(const_cast<char*>(fps[i].get_profile_file_name().c_str())));
-    std::string fit_file_name = pdb_name + "_" + profile_name + ".dat";
+    std::string fit_file_name = pdb_name + "_" + profile_name + ".fit";
     if (i == 0) {
       plt_file << "plot '" << fit_file_name
                << "' u 1:2 t 'Experimental' lc rgb '#333333' pt 6 ps 0.8 ";
     }
-    plt_file << ", '" << fit_file_name << "' u 1:3 t '" << pdb_name
-             << " χ = " << fps[i].get_chi() << "' w lines lw 2.5 lc rgb '#"
+    plt_file << ", '" << fit_file_name << "' u 1:4 t '" << pdb_name
+             << " χ^2 = " << fps[i].get_chi_square() << "' w lines lw 2.5 lc rgb '#"
              << hex_color << "'";
   }
   plt_file << std::endl;
@@ -238,9 +239,9 @@ void Gnuplot::print_canvas_script(
     std::string pdb_name = saxs::trim_extension(fps[i].get_pdb_file_name());
     std::string profile_name = saxs::trim_extension(
         basename(const_cast<char*>(fps[i].get_profile_file_name().c_str())));
-    std::string fit_file_name = pdb_name + "_" + profile_name + ".dat";
+    std::string fit_file_name = pdb_name + "_" + profile_name + ".fit";
     plt_file << ", '" << fit_file_name
-             << "' u 1:($2/$3) w lines lw 2.5 lc rgb '#" << hex_color << "'";
+             << "' u 1:(($2-$4)/$3) w lines lw 2.5 lc rgb '#" << hex_color << "'";
   }
   plt_file << std::endl;
   // actual plots
@@ -251,12 +252,12 @@ void Gnuplot::print_canvas_script(
     std::string pdb_name = saxs::trim_extension(fps[i].get_pdb_file_name());
     std::string profile_name = saxs::trim_extension(
         basename(const_cast<char*>(fps[i].get_profile_file_name().c_str())));
-    std::string fit_file_name = pdb_name + "_" + profile_name + ".dat";
+    std::string fit_file_name = pdb_name + "_" + profile_name + ".fit";
     if (i == 0) {
       plt_file << "plot '" << fit_file_name
                << "' u 1:(log($2)) lc rgb '#333333' pt 6 ps 0.8 ";
     }
-    plt_file << ", '" << fit_file_name << "' u 1:(log($3)) "
+    plt_file << ", '" << fit_file_name << "' u 1:(log($4)) "
              << "w lines lw 2.5 lc rgb '#" << hex_color << "'";
   }
   plt_file << std::endl;
