@@ -3,7 +3,7 @@
  *  \brief A lognormal restraint that uses the ISPA model to model NOE-derived
  *  distance fit.
  *
- *  Copyright 2007-2017 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -11,6 +11,7 @@
 #define IMPISD_GAUSSIAN_RESTRAINT_H
 
 #include <IMP/isd/isd_config.h>
+#include <IMP/isd/FNormal.h>
 #include <IMP/Particle.h>
 #include <IMP/Restraint.h>
 
@@ -19,6 +20,7 @@ IMPISD_BEGIN_NAMESPACE
 //! Normal probability distribution as a restraint
 class IMPISDEXPORT GaussianRestraint : public Restraint {
  private:
+  PointerMember<FNormal> normal_;
   Pointer<Particle> px_;
   double x_;
   Pointer<Particle> pmu_;
@@ -31,6 +33,7 @@ class IMPISDEXPORT GaussianRestraint : public Restraint {
  private:
   void set_chi(double chi) { chi_ = chi; }
   void check_particles();
+  void create_normal();
 
  public:
   //! Gaussian restraint
