@@ -2,7 +2,7 @@
  *  \file IMP/multifit/fitting_states.h
  *  \brief Fitting states
  *
- *  Copyright 2007-2015 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -28,10 +28,10 @@ class IMPMULTIFITEXPORT FittingStates : public domino::ParticleStates {
         fit_state_key_(fit_state_key) {}
 
   virtual unsigned int get_number_of_particle_states() const IMP_OVERRIDE;
-  virtual void load_particle_state(unsigned int, kernel::Particle *) const
+  virtual void load_particle_state(unsigned int, Particle *) const
       IMP_OVERRIDE;
 
-  IMP_OBJECT_NO_WARNING(FittingStates);
+  IMP_OBJECT_METHODS(FittingStates);
 };
 
 IMPMULTIFIT_END_NAMESPACE
