@@ -12,20 +12,6 @@ import os.path
 
 class Tests(IMP.test.TestCase):
 
-    def test_serial(self):
-        """Test the _SerialReplicaExchange class"""
-        s = IMP.pmi.samplers._SerialReplicaExchange()
-        self.assertEqual(s.get_number_of_replicas(), 1)
-        ts = s.create_temperatures(100., 200., 45)
-        self.assertEqual(len(ts), 1)
-        self.assertAlmostEqual(ts[0], 100.0, delta=1e-6)
-        self.assertEqual(s.get_my_index(), 0)
-        self.assertEqual(s.get_friend_index(0), 0)
-        s.set_my_parameter("temp", ['foo', 'bar'])
-        self.assertEqual(s.get_my_parameter("temp"), ['foo', 'bar'])
-        self.assertEqual(s.get_friend_parameter("temp", 0), ['foo', 'bar'])
-        self.assertEqual(s.do_exchange(0, 0, 0), False)
-
     def test_macro(self):
         """setting up the representation
         PMI 1.0 representation. Creates two particles and
@@ -33,7 +19,8 @@ class Tests(IMP.test.TestCase):
         import shutil
         import itertools
         m=IMP.Model()
-        r=IMP.pmi.representation.Representation(m)
+        with IMP.allow_deprecated():
+            r=IMP.pmi.representation.Representation(m)
         r.create_component("A")
         r.add_component_beads("A",[(1,1),(2,2)])
         ps=IMP.atom.get_leaves(r.prot)
@@ -145,7 +132,7 @@ class Tests(IMP.test.TestCase):
                             rmf_file_index])
         nframes=len(d[mc_nframe_key])
         self.assertNotEqual(float(d[mc_nframe_key][-1]), 0)
-        self.assertEqual(map(float,d[mc_temp_key]), [1.0]*nframes)
+        self.assertEqual(list(map(float,d[mc_temp_key])), [1.0]*nframes)
         self.assertGreater(float(d[rex_min_temp_key][-1]), 0.0)
         # always fails
         #self.assertGreater(float(d[rex_max_temp_key][-1]), 0.0)
@@ -170,7 +157,8 @@ class Tests(IMP.test.TestCase):
         import shutil
         import itertools
         m=IMP.Model()
-        r=IMP.pmi.representation.Representation(m)
+        with IMP.allow_deprecated():
+            r=IMP.pmi.representation.Representation(m)
         r.create_component("A")
         r.add_component_beads("A",[(1,1),(2,2)])
         ps=IMP.atom.get_leaves(r.prot)
@@ -283,7 +271,7 @@ class Tests(IMP.test.TestCase):
                             rmf_file_index])
         nframes=len(d[mc_nframe_key])
         self.assertNotEqual(float(d[mc_nframe_key][-1]), 0)
-        self.assertEqual(map(float,d[mc_temp_key]), [1.0]*nframes)
+        self.assertEqual(list(map(float,d[mc_temp_key])), [1.0]*nframes)
         self.assertGreater(float(d[rex_min_temp_key][-1]), 0.0)
         # always fails
         #self.assertGreater(float(d[rex_max_temp_key][-1]), 0.0)
