@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 
-"""Traverses the directory tree deleting any .pyc's who do not have a source .py.
-Helpful when switching between revisions with source control."""
+"""Traverses the directory tree deleting any .pyc's who do not have a
+   source .py. Helpful when switching between revisions with source control."""
+
+from __future__ import print_function
 from os.path import join
 from os import walk, unlink
 import re
@@ -28,4 +30,5 @@ for directory in directories:
             count += 1
 
 if count > 0:
-    print 'Removed \033[91m%d\033[0m file%s' % (count, 's' if count > 1 else '')
+    print('Removed \033[91m%d\033[0m file%s'
+          % (count, 's' if count > 1 else ''))
