@@ -117,18 +117,23 @@ class Tests(IMP.test.TestCase):
         d.dump(po.system, w)
         self.assertEqual(fh.getvalue(), """#
 loop_
-_ihm_multi_state_modeling.ordinal_id
 _ihm_multi_state_modeling.state_id
 _ihm_multi_state_modeling.state_group_id
 _ihm_multi_state_modeling.population_fraction
 _ihm_multi_state_modeling.state_type
 _ihm_multi_state_modeling.state_name
-_ihm_multi_state_modeling.model_group_id
 _ihm_multi_state_modeling.experiment_type
 _ihm_multi_state_modeling.details
-1 1 1 . . . 1 'Fraction of bulk' .
-2 1 1 . . . 2 'Fraction of bulk' .
-3 2 1 . . 'state2 long' 3 'Fraction of bulk' .
+1 1 . . . 'Fraction of bulk' .
+2 1 . . 'state2 long' 'Fraction of bulk' .
+#
+#
+loop_
+_ihm_multi_state_model_group_link.state_id
+_ihm_multi_state_model_group_link.model_group_id
+1 1
+1 2
+2 3
 #
 """)
 
@@ -364,19 +369,29 @@ _ihm_multi_state_modeling.details
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_model_list.ordinal_id
 _ihm_model_list.model_id
-_ihm_model_list.model_group_id
 _ihm_model_list.model_name
-_ihm_model_list.model_group_name
 _ihm_model_list.assembly_id
 _ihm_model_list.protocol_id
 _ihm_model_list.representation_id
-1 1 1 . 'all models' 42 93 99
+1 . 42 93 99
 #
 #
 loop_
-_ihm_sphere_obj_site.ordinal_id
+_ihm_model_group.id
+_ihm_model_group.name
+_ihm_model_group.details
+1 'all models' .
+#
+#
+loop_
+_ihm_model_group_link.group_id
+_ihm_model_group_link.model_id
+1 1
+#
+#
+loop_
+_ihm_sphere_obj_site.id
 _ihm_sphere_obj_site.entity_id
 _ihm_sphere_obj_site.seq_id_begin
 _ihm_sphere_obj_site.seq_id_end
@@ -433,15 +448,25 @@ _ihm_sphere_obj_site.model_id
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_model_list.ordinal_id
 _ihm_model_list.model_id
-_ihm_model_list.model_group_id
 _ihm_model_list.model_name
-_ihm_model_list.model_group_name
 _ihm_model_list.assembly_id
 _ihm_model_list.protocol_id
 _ihm_model_list.representation_id
-1 1 1 . 'all models' 42 93 99
+1 . 42 93 99
+#
+#
+loop_
+_ihm_model_group.id
+_ihm_model_group.name
+_ihm_model_group.details
+1 'all models' .
+#
+#
+loop_
+_ihm_model_group_link.group_id
+_ihm_model_group_link.model_id
+1 1
 #
 #
 loop_
@@ -466,7 +491,7 @@ ATOM 2 . CA . GLU 2 A -8.986 11.688 -5.817 1 A . 1 1
 #
 #
 loop_
-_ihm_sphere_obj_site.ordinal_id
+_ihm_sphere_obj_site.id
 _ihm_sphere_obj_site.entity_id
 _ihm_sphere_obj_site.seq_id_begin
 _ihm_sphere_obj_site.seq_id_end
@@ -522,19 +547,29 @@ _ihm_sphere_obj_site.model_id
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_model_list.ordinal_id
 _ihm_model_list.model_id
-_ihm_model_list.model_group_id
 _ihm_model_list.model_name
-_ihm_model_list.model_group_name
 _ihm_model_list.assembly_id
 _ihm_model_list.protocol_id
 _ihm_model_list.representation_id
-1 1 1 foo 'all models' 42 93 99
+1 foo 42 93 99
 #
 #
 loop_
-_ihm_sphere_obj_site.ordinal_id
+_ihm_model_group.id
+_ihm_model_group.name
+_ihm_model_group.details
+1 'all models' .
+#
+#
+loop_
+_ihm_model_group_link.group_id
+_ihm_model_group_link.model_id
+1 1
+#
+#
+loop_
+_ihm_sphere_obj_site.id
 _ihm_sphere_obj_site.entity_id
 _ihm_sphere_obj_site.seq_id_begin
 _ihm_sphere_obj_site.seq_id_end
@@ -564,6 +599,11 @@ _ihm_sphere_obj_site.model_id
         d = ihm.dumper._StructAsymDumper()
         d.finalize(system)
 
+    def assign_range_ids(self, system):
+        """Assign IDs to all Entity/AsymUnit segments in the system"""
+        d = ihm.dumper._EntityPolySegmentDumper()
+        d.finalize(system)
+
     def test_starting_model_dumper(self):
         """Test StartingModelDumper"""
         m = IMP.Model()
@@ -602,6 +642,7 @@ _ihm_sphere_obj_site.model_id
         ihm.dumper._ExternalReferenceDumper().finalize(po.system)
         ihm.dumper._SoftwareDumper().finalize(po.system)  # assign software IDs
         self.assign_dataset_ids(po)
+        self.assign_range_ids(po.system)
         d = ihm.dumper._StartingModelDumper()
         d.finalize(po.system)
         d.dump(po.system, w)
@@ -612,14 +653,13 @@ _ihm_starting_model_details.starting_model_id
 _ihm_starting_model_details.entity_id
 _ihm_starting_model_details.entity_description
 _ihm_starting_model_details.asym_id
-_ihm_starting_model_details.seq_id_begin
-_ihm_starting_model_details.seq_id_end
+_ihm_starting_model_details.entity_poly_segment_id
 _ihm_starting_model_details.starting_model_source
 _ihm_starting_model_details.starting_model_auth_asym_id
 _ihm_starting_model_details.starting_model_sequence_offset
 _ihm_starting_model_details.dataset_list_id
-1 1 Nup84 A 33 2 'comparative model' A 0 3
-2 2 Nup85 B 26 -5 'comparative model' A -7 4
+1 1 Nup84 A 6 'comparative model' A 0 3
+2 2 Nup85 B 7 'comparative model' A -7 4
 #
 #
 loop_
@@ -631,7 +671,7 @@ _ihm_starting_computational_models.script_file_id
 #
 #
 loop_
-_ihm_starting_comparative_models.ordinal_id
+_ihm_starting_comparative_models.id
 _ihm_starting_comparative_models.starting_model_id
 _ihm_starting_comparative_models.starting_model_auth_asym_id
 _ihm_starting_comparative_models.starting_model_seq_id_begin
@@ -719,25 +759,31 @@ _ihm_starting_model_coord.ordinal_id
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_modeling_protocol.ordinal_id
-_ihm_modeling_protocol.protocol_id
-_ihm_modeling_protocol.step_id
-_ihm_modeling_protocol.struct_assembly_id
-_ihm_modeling_protocol.dataset_group_id
-_ihm_modeling_protocol.struct_assembly_description
+_ihm_modeling_protocol.id
 _ihm_modeling_protocol.protocol_name
-_ihm_modeling_protocol.step_name
-_ihm_modeling_protocol.step_method
-_ihm_modeling_protocol.num_models_begin
-_ihm_modeling_protocol.num_models_end
-_ihm_modeling_protocol.multi_scale_flag
-_ihm_modeling_protocol.multi_state_flag
-_ihm_modeling_protocol.ordered_flag
-_ihm_modeling_protocol.software_id
-_ihm_modeling_protocol.script_file_id
-1 1 1 1 1 'All known components & All components modeled by IMP' . Sampling
+_ihm_modeling_protocol.num_steps
+1 . 2
+#
+#
+loop_
+_ihm_modeling_protocol_details.id
+_ihm_modeling_protocol_details.protocol_id
+_ihm_modeling_protocol_details.step_id
+_ihm_modeling_protocol_details.struct_assembly_id
+_ihm_modeling_protocol_details.dataset_group_id
+_ihm_modeling_protocol_details.struct_assembly_description
+_ihm_modeling_protocol_details.step_name
+_ihm_modeling_protocol_details.step_method
+_ihm_modeling_protocol_details.num_models_begin
+_ihm_modeling_protocol_details.num_models_end
+_ihm_modeling_protocol_details.multi_scale_flag
+_ihm_modeling_protocol_details.multi_state_flag
+_ihm_modeling_protocol_details.ordered_flag
+_ihm_modeling_protocol_details.software_id
+_ihm_modeling_protocol_details.script_file_id
+1 1 1 2 1 'All components modeled by IMP' Sampling
 'Replica exchange monte carlo' 0 1000 YES NO NO . .
-2 1 2 1 1 'All known components & All components modeled by IMP' . Sampling
+2 1 2 2 1 'All components modeled by IMP' Sampling
 'Replica exchange monte carlo' 1000 1000 YES NO NO . .
 #
 """)
@@ -952,8 +998,8 @@ _ihm_modeling_post_process.script_file_id
             self.assertEqual(e.densities[0].file.details,
                          'Localization density for Nup84 dgroup')
             # No precision available
-            self.assertEqual(e._get_precision(), '?')
-            self.assertEqual(e.precision, '?')
+            self.assertEqual(e._get_precision(), ihm.unknown)
+            self.assertEqual(e.precision, ihm.unknown)
             # Make precision available
             with open(os.path.join(tmpdir, 'precision.0.0.out'), 'w') as fh:
                 fh.write("""
@@ -1058,6 +1104,7 @@ _ihm_ensemble_info.ensemble_file_id
 
         fh = StringIO()
         self.assign_entity_asym_ids(po.system)
+        self.assign_range_ids(po.system)
         w = ihm.format.CifWriter(fh)
         d = ihm.dumper._DensityDumper()
         d.finalize(po.system)
@@ -1070,9 +1117,8 @@ _ihm_localization_density_files.file_id
 _ihm_localization_density_files.ensemble_id
 _ihm_localization_density_files.entity_id
 _ihm_localization_density_files.asym_id
-_ihm_localization_density_files.seq_id_begin
-_ihm_localization_density_files.seq_id_end
-1 97 42 1 A 1 4
+_ihm_localization_density_files.entity_poly_segment_id
+1 97 42 1 A 1
 #
 """)
 
@@ -1119,6 +1165,8 @@ _ihm_localization_density_files.seq_id_end
 
         fh = StringIO()
         self.assign_entity_asym_ids(po.system)
+        d = ihm.dumper._ChemDescriptorDumper()
+        d.finalize(po.system) # Assign chemical descriptor IDs
         w = ihm.format.CifWriter(fh)
         d = ihm.dumper._CrossLinkDumper()
         d.finalize(po.system)
@@ -1136,10 +1184,11 @@ _ihm_cross_link_list.entity_description_2
 _ihm_cross_link_list.entity_id_2
 _ihm_cross_link_list.seq_id_2
 _ihm_cross_link_list.comp_id_2
+_ihm_cross_link_list.linker_chem_comp_descriptor_id
 _ihm_cross_link_list.linker_type
 _ihm_cross_link_list.dataset_list_id
-1 1 Nup84 1 1 MET Nup84 1 2 GLU foo 42
-2 2 Nup84 1 1 MET Nup84 1 3 LEU foo 42
+1 1 Nup84 1 1 MET Nup84 1 2 GLU 1 foo 42
+2 2 Nup84 1 1 MET Nup84 1 3 LEU 1 foo 42
 #
 #
 loop_
@@ -1236,11 +1285,11 @@ _ihm_2dem_class_average_restraint.image_segment_flag
 _ihm_2dem_class_average_restraint.number_of_projections
 _ihm_2dem_class_average_restraint.struct_assembly_id
 _ihm_2dem_class_average_restraint.details
-1 4 50 4.200 4.200 1.000 NO 200 1 .
+1 4 50 4.200 4.200 1.000 NO 200 2 .
 #
 #
 loop_
-_ihm_2dem_class_average_fitting.ordinal_id
+_ihm_2dem_class_average_fitting.id
 _ihm_2dem_class_average_fitting.restraint_id
 _ihm_2dem_class_average_fitting.model_id
 _ihm_2dem_class_average_fitting.cross_correlation_coefficient
@@ -1263,38 +1312,7 @@ _ihm_2dem_class_average_fitting.tr_vector[3]
 
     def test_add_zaxial_restraint(self):
         """Test add_zaxial_restraint method"""
-        class MockObject(object):
-            pass
-        m = IMP.Model()
-        simo = IMP.pmi1.representation.Representation(m)
-        po = DummyPO(None)
-        simo.add_protocol_output(po)
-        state = simo._protocol_output[0][1]
-
-        simo.create_component("Nup84", True)
-        simo.add_component_sequence("Nup84",
-                                    self.get_input_file_name("test.fasta"))
-        nup84 = simo.autobuild_model("Nup84",
-                                     self.get_input_file_name("test.nup84.pdb"),
-                                     "A")
-        residues = IMP.pmi1.tools.select_by_tuple(simo, "Nup84", resolution=1)
-        cterm = residues[-1:]
-        nterm = residues[:1]
-        pmi_r = MockObject()
-        pmi_r.dataset = None
-        po.add_zaxial_restraint(state, nterm + cterm, lower_bound=4.0,
-                                upper_bound=8.0, sigma=2.0, pmi_restraint=pmi_r)
-        self.assertRaises(ValueError, po.add_zaxial_restraint,
-                          state, [simo.hier_dict['Nup84']], lower_bound=4.0,
-                          upper_bound=8.0, sigma=2.0, pmi_restraint=pmi_r)
-        self.assign_entity_asym_ids(po.system)
-        d = ihm.dumper._GeometricObjectDumper()
-        d.finalize(po.system)
-        fh = StringIO()
-        w = ihm.format.CifWriter(fh)
-        d.dump(po.system, w)
-        out = fh.getvalue()
-        self.assertEqual(out, """#
+        self._check_geom_restraint('add_zaxial_restraint', """#
 loop_
 _ihm_geometric_object_list.object_id
 _ihm_geometric_object_list.object_type
@@ -1310,6 +1328,128 @@ _ihm_geometric_object_plane.plane_type
 _ihm_geometric_object_plane.transformation_id
 1 xy-plane .
 #
+""")
+
+    def test_add_yaxial_restraint(self):
+        """Test add_yaxial_restraint method"""
+        self._check_geom_restraint('add_yaxial_restraint', """#
+loop_
+_ihm_geometric_object_list.object_id
+_ihm_geometric_object_list.object_type
+_ihm_geometric_object_list.object_name
+_ihm_geometric_object_list.object_description
+_ihm_geometric_object_list.other_details
+1 plane . . .
+#
+#
+loop_
+_ihm_geometric_object_plane.object_id
+_ihm_geometric_object_plane.plane_type
+_ihm_geometric_object_plane.transformation_id
+1 xz-plane .
+#
+""")
+
+    def test_add_xyradial_restraint(self):
+        """Test add_xyradial_restraint method"""
+        self._check_geom_restraint('add_xyradial_restraint', """#
+loop_
+_ihm_geometric_object_list.object_id
+_ihm_geometric_object_list.object_type
+_ihm_geometric_object_list.object_name
+_ihm_geometric_object_list.object_description
+_ihm_geometric_object_list.other_details
+1 axis . . .
+#
+#
+loop_
+_ihm_geometric_object_axis.object_id
+_ihm_geometric_object_axis.axis_type
+_ihm_geometric_object_axis.transformation_id
+1 z-axis .
+#
+""")
+
+    def _check_geom_restraint(self, method_name, expected_output):
+        class MockObject(object):
+            pass
+        m = IMP.Model()
+        simo = IMP.pmi1.representation.Representation(m)
+        po = DummyPO(None)
+        simo.add_protocol_output(po)
+        state = simo._protocol_output[0][1]
+
+        simo.create_component("Nup84", True)
+        simo.add_component_sequence("Nup84",
+                                    self.get_input_file_name("test.fasta"))
+        nup84 = simo.autobuild_model("Nup84",
+                                     self.get_input_file_name("test.nup84.pdb"),
+                                     "A")
+        residues = IMP.pmi1.tools.select_by_tuple(simo, "Nup84", resolution=1)
+        pmi_r = MockObject()
+        pmi_r.dataset = None
+        method = getattr(po, method_name)
+        method(state, residues, lower_bound=4.0,
+               upper_bound=8.0, sigma=2.0, pmi_restraint=pmi_r)
+        self.assertRaises(ValueError, method,
+                          state, [simo.hier_dict['Nup84']], lower_bound=4.0,
+                          upper_bound=8.0, sigma=2.0, pmi_restraint=pmi_r)
+        self.assign_entity_asym_ids(po.system)
+        d = ihm.dumper._GeometricObjectDumper()
+        d.finalize(po.system)
+        fh = StringIO()
+        w = ihm.format.CifWriter(fh)
+        d.dump(po.system, w)
+        out = fh.getvalue()
+        self.assertEqual(out, expected_output)
+        d = ihm.dumper._FeatureDumper()
+        d.finalize(po.system)
+        fh = StringIO()
+        w = ihm.format.CifWriter(fh)
+        d.dump(po.system, w)
+        out = fh.getvalue()
+        self.assertEqual(out, """#
+loop_
+_ihm_feature_list.feature_id
+_ihm_feature_list.feature_type
+_ihm_feature_list.entity_type
+1 'residue range' polymer
+#
+#
+loop_
+_ihm_poly_residue_feature.ordinal_id
+_ihm_poly_residue_feature.feature_id
+_ihm_poly_residue_feature.entity_id
+_ihm_poly_residue_feature.asym_id
+_ihm_poly_residue_feature.seq_id_begin
+_ihm_poly_residue_feature.comp_id_begin
+_ihm_poly_residue_feature.seq_id_end
+_ihm_poly_residue_feature.comp_id_end
+1 1 1 A 1 MET 1 MET
+2 1 1 A 2 GLU 2 GLU
+3 1 1 A 3 LEU 4 SER
+#
+""")
+        d = ihm.dumper._GeometricRestraintDumper()
+        d.finalize(po.system)
+        fh = StringIO()
+        w = ihm.format.CifWriter(fh)
+        d.dump(po.system, w)
+        out = fh.getvalue()
+        self.assertEqual(out, """#
+loop_
+_ihm_geometric_object_distance_restraint.id
+_ihm_geometric_object_distance_restraint.object_id
+_ihm_geometric_object_distance_restraint.feature_id
+_ihm_geometric_object_distance_restraint.object_characteristic
+_ihm_geometric_object_distance_restraint.restraint_type
+_ihm_geometric_object_distance_restraint.harmonic_force_constant
+_ihm_geometric_object_distance_restraint.distance_lower_limit
+_ihm_geometric_object_distance_restraint.distance_upper_limit
+_ihm_geometric_object_distance_restraint.group_conditionality
+_ihm_geometric_object_distance_restraint.dataset_list_id
+1 1 1 other 'lower and upper bound' 0.500 4.000 8.000 ALL .
+#
 """)
 
     def test_get_membrane(self):
@@ -1325,6 +1465,17 @@ _ihm_geometric_object_plane.transformation_id
 
     def test_add_membrane_surface_restraint(self):
         """Test add_membrane_surface_restraint method"""
+        self._check_membrane_restraint(
+                   'add_membrane_surface_location_restraint',
+                   "'upper bound' 0.500 . 0.000")
+
+    def test_add_membrane_exclusion_restraint(self):
+        """Test add_membrane_exclusion_restraint method"""
+        self._check_membrane_restraint(
+                   'add_membrane_exclusion_restraint',
+                   "'lower bound' 0.500 0.000 .")
+
+    def _check_membrane_restraint(self, method_name, expected_dist_rsr):
         class MockObject(object):
             pass
         m = IMP.Model()
@@ -1343,9 +1494,9 @@ _ihm_geometric_object_plane.transformation_id
         nterm = residues[:1]
         pmi_r = MockObject()
         pmi_r.dataset = None
-        po.add_membrane_surface_location_restraint(
-                state, nterm, tor_R=4.0, tor_r=1.0, tor_th=0.1, sigma=2.0,
-                pmi_restraint=pmi_r)
+        method = getattr(po, method_name)
+        method(state, nterm, tor_R=4.0, tor_r=1.0, tor_th=0.1, sigma=2.0,
+               pmi_restraint=pmi_r)
         self.assign_entity_asym_ids(po.system)
         d = ihm.dumper._GeometricObjectDumper()
         d.finalize(po.system)
@@ -1451,9 +1602,9 @@ _ihm_geometric_object_distance_restraint.distance_lower_limit
 _ihm_geometric_object_distance_restraint.distance_upper_limit
 _ihm_geometric_object_distance_restraint.group_conditionality
 _ihm_geometric_object_distance_restraint.dataset_list_id
-1 1 1 other 'upper bound' 0.500 . 0.000 ALL .
+1 1 1 other %s ALL .
 #
-""")
+""" % expected_dist_rsr)
 
     def test_sas_dumper(self):
         """Test SASDumper class"""
@@ -1485,7 +1636,7 @@ _ihm_geometric_object_distance_restraint.dataset_list_id
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_sas_restraint.ordinal_id
+_ihm_sas_restraint.id
 _ihm_sas_restraint.dataset_list_id
 _ihm_sas_restraint.model_id
 _ihm_sas_restraint.struct_assembly_id
@@ -1496,7 +1647,7 @@ _ihm_sas_restraint.fitting_state
 _ihm_sas_restraint.radius_of_gyration
 _ihm_sas_restraint.chi_value
 _ihm_sas_restraint.details
-1 4 42 2 NO 'Heavy atoms' FoXS Single 3.400 1.200 test
+1 4 42 3 NO 'Heavy atoms' FoXS Single 3.400 1.200 test
 #
 """)
 
@@ -1550,7 +1701,7 @@ _ihm_sas_restraint.details
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_3dem_restraint.ordinal_id
+_ihm_3dem_restraint.id
 _ihm_3dem_restraint.dataset_list_id
 _ihm_3dem_restraint.fitting_method
 _ihm_3dem_restraint.fitting_method_citation_id
@@ -1558,8 +1709,8 @@ _ihm_3dem_restraint.struct_assembly_id
 _ihm_3dem_restraint.number_of_gaussians
 _ihm_3dem_restraint.model_id
 _ihm_3dem_restraint.cross_correlation_coefficient
-1 4 'Gaussian mixture models' . 1 2 5 0.100
-2 4 'Gaussian mixture models' . 1 2 9 0.200
+1 4 'Gaussian mixture models' . 2 2 5 0.100
+2 4 'Gaussian mixture models' . 2 2 9 0.200
 #
 """)
 
@@ -1697,7 +1848,7 @@ _ihm_3dem_restraint.cross_correlation_coefficient
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_starting_model_seq_dif.ordinal_id
+_ihm_starting_model_seq_dif.id
 _ihm_starting_model_seq_dif.entity_id
 _ihm_starting_model_seq_dif.asym_id
 _ihm_starting_model_seq_dif.seq_id
@@ -1737,7 +1888,7 @@ _ihm_starting_model_seq_dif.details
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_starting_model_seq_dif.ordinal_id
+_ihm_starting_model_seq_dif.id
 _ihm_starting_model_seq_dif.entity_id
 _ihm_starting_model_seq_dif.asym_id
 _ihm_starting_model_seq_dif.seq_id
@@ -1832,29 +1983,37 @@ _ihm_starting_model_seq_dif.details
         fh = StringIO()
         w = ihm.format.CifWriter(fh)
         self.assign_entity_asym_ids(po.system)
+        self.assign_range_ids(po.system)
         # Need this to assign starting model details
         ihm.dumper._StartingModelDumper().finalize(po.system)
         d = ihm.dumper._ModelRepresentationDumper()
         d.finalize(po.system)
         d.dump(po.system, w)
+        r, = po.system.orphan_representations
+        self.assertEqual([f.asym_unit.seq_id_range for f in r], [(1,2), (1,2)])
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_model_representation.ordinal_id
-_ihm_model_representation.representation_id
-_ihm_model_representation.segment_id
-_ihm_model_representation.entity_id
-_ihm_model_representation.entity_description
-_ihm_model_representation.entity_asym_id
-_ihm_model_representation.seq_id_begin
-_ihm_model_representation.seq_id_end
-_ihm_model_representation.model_object_primitive
-_ihm_model_representation.starting_model_id
-_ihm_model_representation.model_mode
-_ihm_model_representation.model_granularity
-_ihm_model_representation.model_object_count
-1 1 1 1 Nup84 A 1 2 sphere 1 flexible by-residue .
-2 1 2 1 Nup84 B 1 2 sphere 1 flexible by-residue .
+_ihm_model_representation.id
+_ihm_model_representation.name
+_ihm_model_representation.details
+1 . .
+#
+#
+loop_
+_ihm_model_representation_details.id
+_ihm_model_representation_details.representation_id
+_ihm_model_representation_details.entity_id
+_ihm_model_representation_details.entity_description
+_ihm_model_representation_details.entity_asym_id
+_ihm_model_representation_details.entity_poly_segment_id
+_ihm_model_representation_details.model_object_primitive
+_ihm_model_representation_details.starting_model_id
+_ihm_model_representation_details.model_mode
+_ihm_model_representation_details.model_granularity
+_ihm_model_representation_details.model_object_count
+1 1 1 Nup84 A 1 sphere 1 flexible by-residue .
+2 1 1 Nup84 B 1 sphere 1 flexible by-residue .
 #
 """)
 
@@ -1875,29 +2034,37 @@ _ihm_model_representation.model_object_count
         fh = StringIO()
         w = ihm.format.CifWriter(fh)
         self.assign_entity_asym_ids(po.system)
+        self.assign_range_ids(po.system)
         # Need this to assign starting model details
         ihm.dumper._StartingModelDumper().finalize(po.system)
         d = ihm.dumper._ModelRepresentationDumper()
         d.finalize(po.system)
         d.dump(po.system, w)
+        r, = po.system.orphan_representations
+        self.assertEqual([f.asym_unit.seq_id_range for f in r], [(1,2), (3,4)])
         out = fh.getvalue()
         self.assertEqual(out, """#
 loop_
-_ihm_model_representation.ordinal_id
-_ihm_model_representation.representation_id
-_ihm_model_representation.segment_id
-_ihm_model_representation.entity_id
-_ihm_model_representation.entity_description
-_ihm_model_representation.entity_asym_id
-_ihm_model_representation.seq_id_begin
-_ihm_model_representation.seq_id_end
-_ihm_model_representation.model_object_primitive
-_ihm_model_representation.starting_model_id
-_ihm_model_representation.model_mode
-_ihm_model_representation.model_granularity
-_ihm_model_representation.model_object_count
-1 1 1 1 Nup84 A 1 2 sphere 1 rigid by-residue .
-2 1 2 1 Nup84 A 3 4 sphere . flexible by-feature 1
+_ihm_model_representation.id
+_ihm_model_representation.name
+_ihm_model_representation.details
+1 . .
+#
+#
+loop_
+_ihm_model_representation_details.id
+_ihm_model_representation_details.representation_id
+_ihm_model_representation_details.entity_id
+_ihm_model_representation_details.entity_description
+_ihm_model_representation_details.entity_asym_id
+_ihm_model_representation_details.entity_poly_segment_id
+_ihm_model_representation_details.model_object_primitive
+_ihm_model_representation_details.starting_model_id
+_ihm_model_representation_details.model_mode
+_ihm_model_representation_details.model_granularity
+_ihm_model_representation_details.model_object_count
+1 1 1 Nup84 A 1 sphere 1 rigid by-residue .
+2 1 1 Nup84 A 2 sphere . flexible by-feature 1
 #
 """)
 
