@@ -2,7 +2,7 @@
  *  \file RMF/HDF5/ConstAttributes.h
  *  \brief Handle read/write of Model data from/to files.
  *
- *  Copyright 2007-2016 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2019 IMP Inventors. All rights reserved.
  *
  */
 
@@ -21,7 +21,7 @@ namespace RMF {
 namespace HDF5 {
 
 /** Wrap an gettings the attributes from an HDF5 Object. Each data set or
-    group can have associated data. These data should be relativel small
+    group can have associated data. These data should be relatively small
     (a few k at most). See MutableAttributes for the methods to change
     the attribute data.
  */
@@ -37,7 +37,7 @@ class ConstAttributes : public Base {
 #endif
  public:
   /** \name Template attribute methods
-      When manipulating attriutes from C++ you can use these
+      When manipulating attributes from C++ you can use these
       templated methods.
       @{
    */
